Changelog
=========

0.1.2 (December 12, 2014)
-------------------------

* Added support for Python 3.2.
* Added support for .puz puzzles.

0.1.1 (August 19, 2014)
-----------------------

* Fixed reading .ipuz puzzles that do not have a solution element.
* Fixed reading .ipuz puzzles that do not have Across and/or Down clues.
* Fixed writing .ipuz puzzles to only include "block" and/or "empty" when specified.

0.1 (August 17, 2014)
---------------------

* Initial release.
